@@ -8,10 +8,17 @@
 #include "logging.h"
 #include "scopedxmlstreamreader.h"
 
+#include <KPublicTransport/IndividualTransport>
 #include <KPublicTransport/Path>
 
 using namespace KPublicTransport;
 
+bool EfaRequestContext::isEmpty() const
+{
+    return sessionId.isEmpty() || requestId.isEmpty() || sessionId == QLatin1String("0");
+}
+
+
 EfaParser::~EfaParser() = default;
 
 void EfaParser::setLocationIdentifierType(const QString& locationIdentifierType)
@@ -56,11 +63,25 @@ Line::Mode EfaParser::motTypeToLineMode(int mot)
         case 18: return Line::Train; // "Rail shuttle"
         case 19: return Line::Bus; // "Peoples bus" / "Bürgerbus"
     }
-    qCDebug(Log) << "Unknown means ot transport: " << mot;
+    qCDebug(Log) << "Unknown means of transport: " << mot;
     return Line::Unknown;
 }
 
-Path EfaParser::parsePathCoordinatesElement(ScopedXmlStreamReader &reader)
+IndividualTransport EfaParser::motTypeToIndividualTransportMode(int mot)
+{
+    switch (mot) {
+        case 100: return { IndividualTransport::Walk, IndividualTransport::None };
+        case 101: return { IndividualTransport::Bike, IndividualTransport::Park };
+        case 102: return { IndividualTransport::Bike, IndividualTransport::None };
+        case 103:
+        case 104:
+            return { IndividualTransport::Car, IndividualTransport::None }; // TODO
+    }
+    qCDebug(Log) << "Unknown means of individual transport: " << mot;
+    return IndividualTransport::Walk;
+}
+
+QPolygonF EfaParser::parsePathCoordinatesElement(ScopedXmlStreamReader &reader)
 {
     QPolygonF poly;
     // TODO do we need to support the format attributes, or is this always the same anyway?
@@ -72,7 +93,11 @@ Path EfaParser::parsePathCoordinatesElement(ScopedXmlStreamReader &reader)
             poly.push_back({p[0].toDouble(), p[1].toDouble()});
         }
     }
+    return poly;
+}
 
+Path EfaParser::polygonToPath(const QPolygonF &poly)
+{
     PathSection section;
     section.setPath(poly);
     Path path;
@@ -84,3 +109,28 @@ bool EfaParser::isDummyStopId(QStringView id)
 {
     return id == QLatin1String("99999997") || id == QLatin1String("99999998");
 }
+
+EfaRequestContext EfaParser::requestContext() const
+{
+    return m_requestContext;
+}
+
+QHash<QString, QString> EfaParser::parseKeyValueList(ScopedXmlStreamReader &&reader, QLatin1String elemName, QLatin1String keyName, QLatin1String valueName)
+{
+    QHash<QString, QString> attrs;
+    while (reader.readNextSibling()) {
+        if (reader.name() == elemName) {
+            auto attrReader = reader.subReader();
+            QString name, value;
+            while (attrReader.readNextSibling()) {
+                if (attrReader.name() == keyName) {
+                    name = attrReader.readElementText();
+                } else if (attrReader.name() == valueName) {
+                    value = attrReader.readElementText();
+                }
+            }
+            attrs.insert(name, value);
+        }
+    }
+    return attrs;
+}
