@@ -64,6 +64,7 @@ private Q_SLOTS:
         // international
         // TODO un_gbfs - this needs special-casing given it cannot do journey and departure searches
         QTest::newRow("un_navitia") << "un_navitia" << loc("Paris Gare de Lyon", 48.84444, 2.37412) << loc("Paris Aéroport Charles de Gaulle 2 TGV", 49.00423, 2.57215);
+        QTest::newRow("un_navitia_qld") << "un_navitia" << loc("Brisbane King George Square Station",  -27.468903869, 153.0242799) << loc("Brisbane International Airport", -27.40029526, 153.0242500);
 
         // national
         QTest::newRow("at_oebb") << "at_oebb" << loc("Wien Hauptbahnhof", 48.18282, 16.37859) << loc("Linz/Donau Hbf", 48.29058, 14.29018);
@@ -175,6 +176,14 @@ private Q_SLOTS:
             QEXPECT_FAIL("it_21_torino", "needs investigation", Continue);
             QEXPECT_FAIL("us_ga_marta", "needs investigation", Continue);
             QVERIFY(reply->result().size() > 0);
+            const auto results = reply->takeResult();
+            if (!results.empty()) {
+                // sanity check the result, should be close enough to where we expect it
+                // there can be valid deviations of a few km due to lack of precision in our test data and
+                // the use of fairly large objects like airports
+                const auto d = Location::distance(loc1.latitude(), loc1.longitude(), results[0].latitude(), results[0].longitude());
+                QVERIFY(std::isnan(d) || d < 10'000);
+            }
         }
 
         // location search by coordinate
